@@ -1,4 +1,4 @@
-/*	$OpenBSD: lpr.c,v 1.34 2003/06/02 23:36:53 millert Exp $ */
+/*	$OpenBSD: lpr.c,v 1.37 2005/03/25 16:54:17 jaredy Exp $ */
 /*	$NetBSD: lpr.c,v 1.19 2000/10/11 20:23:52 is Exp $	*/
 
 /*
@@ -46,7 +46,7 @@ static const char copyright[] =
 #if 0
 static const char sccsid[] = "@(#)lpr.c	8.4 (Berkeley) 4/28/95";
 #else
-static const char rcsid[] = "$OpenBSD: lpr.c,v 1.34 2003/06/02 23:36:53 millert Exp $";
+static const char rcsid[] = "$OpenBSD: lpr.c,v 1.37 2005/03/25 16:54:17 jaredy Exp $";
 #endif
 #endif /* not lint */
 
@@ -115,7 +115,7 @@ static char	*lmktemp(char *, int, int);
 static void	 mktemps(void);
 static int	 nfile(char *);
 static int	 test(char *);
-static __dead void usage(void);
+static void 	usage(void);
 
 int
 main(int argc, char **argv)
@@ -133,8 +133,8 @@ main(int argc, char **argv)
 	 * requires that the lpr binary be owned by user daemon, which
 	 * is potentially unsafe.
 	 */
-	if ((pw = getpwuid(DEFUID)) == NULL)
-		errx(1, "daemon uid (%u) not in password file", DEFUID);
+	if ((pw = getpwnam(DEFUID)) == NULL)
+		errx(1, "'lp' uid not in password file");
 	effective_uid = pw->pw_uid;
 	real_uid = getuid();
 	effective_gid = pw->pw_gid;
@@ -155,7 +155,7 @@ main(int argc, char **argv)
 	openlog("lpr", 0, LOG_LPR);
 
 	while ((ch = getopt(argc, argv,
-	    ":#:1:2:3:4:C:J:P:T:U:cdfghi:lmnpqrstvw:")) != -1) {
+	    ":#:1:2:3:4:C:J:P:T:U:cdfghi::lmnpqrstvw:")) != -1) {
 		switch (ch) {
 
 		case '#':		/* n copies */
@@ -169,7 +169,7 @@ main(int argc, char **argv)
 		case '3':
 		case '2':
 		case '1':
-			fonts[optopt - '1'] = optarg;
+			fonts[ch - '1'] = optarg;
 			break;
 
 		case 'C':		/* classification spec */
@@ -203,7 +203,7 @@ main(int argc, char **argv)
 		case 'p':		/* print using ``pr'' */
 		case 't':		/* print troff output (cat files) */
 		case 'v':		/* print vplot output */
-			format = optopt;
+			format = ch;
 			break;
 
 		case 'f':		/* print fortran output */
@@ -216,8 +216,7 @@ main(int argc, char **argv)
 
 		case 'i':		/* indent output */
 			iflag++;
-			indent = atoi(optarg);
-			if (indent < 0)
+			if ( optarg == 0 || (indent = atoi(optarg)) < 0)
 				indent = 8;
 			break;
 
@@ -241,14 +240,6 @@ main(int argc, char **argv)
 			width = optarg;
 			break;
 
-		case ':':               /* catch "missing argument" error */
-			if (optopt == 'i') {
-				iflag++; /* -i without args is valid */
-				indent = 8;
-			} else
-				usage();
-			break;
-
 		default:
 			usage();
 		}
@@ -301,7 +292,7 @@ main(int argc, char **argv)
 	tfd = nfile(tfname);
 	card('H', host);
 	card('P', person);
-	if (hdr && !SH) {
+	if (hdr) {
 		if (jobname == NULL) {
 			if (argc == 0)
 				jobname = "stdin";
@@ -311,7 +302,8 @@ main(int argc, char **argv)
 		}
 		card('J', jobname);
 		card('C', class);
-		card('L', person);
+		if (!SH)
+			card('L', person);
 	}
 	if (iflag)
 		card('I', itoa(indent));
@@ -341,7 +333,7 @@ main(int argc, char **argv)
 
 		if (sflag && (cp = linked(arg)) != NULL) {
 			(void)snprintf(buf, sizeof(buf), "%d %d",
-			    statb.st_dev, statb.st_ino);
+			    makedev( major(statb.st_dev), minor(statb.st_dev)), (int)statb.st_ino);
 			card('S', buf);
 			if (format == 'p')
 				card('T', title ? title : arg);
@@ -660,7 +652,7 @@ chkprinter(char *s)
 	if (cgetnum(bp,"mc", &MC) < 0)
 		MC = DEFMAXCOPIES;
 	if (cgetnum(bp, "du", &DU) < 0)
-		DU = DEFUID;
+		DU = DEFNUID;
 	SC = (cgetcap(bp, "sc", ':') != NULL);
 	SH = (cgetcap(bp, "sh", ':') != NULL);
 }
@@ -721,7 +713,7 @@ lmktemp(char *id, int num, int len)
 	return(s);
 }
 
-static __dead void
+static  void
 usage(void)
 {
 	extern char *__progname;
